@@ -4,14 +4,14 @@ from pathlib import Path
 
 cache	= os.getenv("spacy_lmdb_cache", str(Path.home()) + "/.cache/lmdb-spacy311")
 try:
-	Path(cache).mkdir() 
+	Path(cache).mkdir()  #FileNotFoundError: [Errno 2] No such file or directory: 'C:\\Users\\zhang/.cache/lmdb-spacy311'
 except Exception as ex:
 	pass 
 env		= lmdb.open(cache, map_size=int(1e9))  
 #if not hasattr(spacy, 'nlp'):
 from spacy.lang import en
 sntbr	= (inst := en.English(), inst.add_pipe("sentencizer"))[0]
-snts	= lambda essay: [ snt.text.strip() for snt in  sntbr(essay).sents]
+snts	= lambda essay, trim=True: [ snt.text.strip() if trim else snt.text for snt in  sntbr(essay).sents]
 sntpid	= lambda essay: (pid:=0, [ ( pid := pid + 1 if "\n" in snt.text else pid,  (snt.text.strip(), pid))[-1] for snt in  sntbr(essay).sents] )[-1]
 nlp		= spacy.load('en_core_web_sm')
 frombs	= lambda bs: list(spacy.tokens.DocBin().from_bytes(bs).get_docs(nlp.vocab))[0] if bs else None
