@@ -9,7 +9,7 @@ now	= lambda: time.strftime('%Y.%m.%d %H:%M:%S',time.localtime(time.time()))
 
 @app.get('/')
 def home(): 
-	return HTMLResponse(content=f"<h2>{getattr(app,'title')}</h2><a href='/docs'> docs </a> | <a href='/redoc'> redoc </a><br>uvicorn uvirun:app --port 80 --host 0.0.0.0 --reload <br><br>last update: {app.tm} <br> started: {now()}")
+	return HTMLResponse(content=f"<h2>{getattr(app,'title') if hasattr(app,'title') else None}</h2><a href='/docs'> docs </a> | <a href='/redoc'> redoc </a><br>uvicorn uvirun:app --port 80 --host 0.0.0.0 --reload <br><br>last update: {getattr(app,'tm')  if hasattr(app,'tm') else None} <br> started: {now()}")
 # app.title = "hello" 
 # app.tm = "2022.2.13"
 
@@ -37,5 +37,4 @@ routes = [
 ]
 
 app=FastAPI(routes=routes)
-
 '''
\ No newline at end of file
